# rb_conclas

O rb_conclas é um client escrito em Ruby para utilizar o serviço Conclas

# Métodos
Antes de mais nada, devemos importar a classe Api que possui os dois métodos principais, sendo eles: o **direct_categorise()** e o **indirect_categorise()**. A classe Api fica dentro do módulo *Conclas*. Sendo assim, vejamos o exemplo abaixo:

```ruby
require 'rb_conclas'
```

## *indirect_categorise()*
O método *indirect_categorise()* faz uma requisição no endpoint *categorise* da API. Ele permite que caso os conteúdos ainda não tenham sidos classificados, jogue-os diretamente em uma fila para classificação.

| Parâmetro           | Descrição                                                     | Tipo | Exigido? |
|---------------------|---------------------------------------------------------------|------|----------|
| contents            | Passa uma lista de conteúdos utilizados no json da requisição. | Array | Sim      |
## *direct_categorise()*
O método *direct_categorise()* faz uma requisição no endpoint *direct_categorise* da API. Este método permite que caso os conteúdos não tenham sido classficados ainda, faça com que esta request seja bloqueada até o conteúdo ser classificado.

| Parâmetro           | Descrição                                                       | Tipo | Exigido? |
|---------------------|-----------------------------------------------------------------|------|----------|
| contents            | Passa uma lista de conteúdos utilizados no json da requisição.   | Array | Sim      |
| callback            | Passa uma url para ser chamada após o término da categorização. | String  | Sim      |
### Parâmetro *contents*
O parâmetro *contents* é muito importante para a requisição, pois nele contém os dados a serem analisados pela API. Ele possui uma lista de dicionários, onde cada dicionário pode conter uma doc(uma chave "values") ou uma url(uma chave "url") mas nunca as duas no mesmo dicionário.

A doc nada mais é do que um dicionário, que poderá receber os seguintes valores.

| Parâmetro  | Descrição                                                                             |
|------------|---------------------------------------------------------------------------------------|
| short_text | Corresponde a uma breve descrição do conteúdo a ser analisado. Geralmente é o título. |
| long_text  | Corresponde ao conteúdo a ser analisado.                                              |
| brands     | Corresponde a marcas que ajudam na categorização do conteúdo.                         |
## Exemplo de utilização

```ruby
require 'rb_conclas'

api = Conclas::Api.new("c6887e5fcff94746bc5f-2a931ed27123")

contents = [
  {
      "url" => "meusite.com"
  },
  {
      "doc" => {
        "short_text" => "Título da documento",
        "long_text" => "Conteúdo do página",
        "brands" => "apple samsung"
      }
  }
]

api.direct_categorise(contents)
puts api.result
```
Após realizar alguma requisição(seja através do método direct ou indirect) o *rb_conclas* popula algumas variáveis que nos fornecem informações como: headers, código de status e resultado da requisição. Essas propriedades são: **headers**, **result** e **status_code**.

| Propriedade | Descrição                                                                            | Tipo                                          |
|-------------|--------------------------------------------------------------------------------------|-----------------------------------------------|
| status_code | Código de status da requisição.(Exemplo, pode retornar 200, caso tudo tenha sido OK) | Fixnum                                           |
| result      | Resultado da requisição, geralmente vem em forma JSON.                               | Hash                                           |
| headers     | Mostra os headers da requisição                                                      | Hash |
